# Uno-Game
A Uno game implemented in Python

Currently a placeholder but may be updated in the future.

## Installation

```bash
pip install pyuno-game
```

## Rules

Official Rules can be found [here](https://service.mattel.com/us/instruction_sheets.aspx).
Do note that there are many variations of the game (also known as Theme Packs) and the rules can be very different.
The target of this project is to implement the original uno game, and potentially allow for customisation as extensions.

Some most popular (citation required) rules is listed below, and also can be found under the [rules](rules/) folder.

- UNO Flip™ (2019) - [rules](rules/GDG37-Eng.pdf)
- UNO® Card Game (2016) - [rules](rules/FFK04-Eng.pdf)
- UNO® Card Game (2010) - [rules](rules/41940-Eng.pdf)
- UNO® Card Game (2008?) - [rules](rules/UNO%20Basic%20IS.pdf)

The last one above is the one wildly used by 3rd party website including [Wikipeida](https://en.wikipedia.org/wiki/Uno_(card_game)#cite_note-UNO-6)
and [Mattel Wiki](https://mattel.fandom.com/wiki/UNO#cite_note-UNO-4), but it can't be found on the official website
(Although the file is still on the server, the product page offers a different version of the rules, which is also provided above).
